==> 3.0.0.tar.gz: ios/Classes/DatabaseManager.swift <==
import Foundation
import SQLite3

class DatabaseManager {
    static let shared = DatabaseManager() // Singleton instance

    private var db: OpaquePointer? = nil

    private init() {
        openDatabase()
    }

    private func openDatabase() {
        let dbPath = NSSearchPathForDirectoriesInDomains(.documentDirectory, .userDomainMask, true).first! + "/myDatabase.db"

        if sqlite3_open(dbPath, &db) == SQLITE_OK {
            print("DatabaseManager Successfully opened connection to database.")
        } else {
            let errorMessage = String(cString: sqlite3_errmsg(db)!)
            print("DatabaseManager Unable to open database. Error: \(errorMessage)")
        }
    }

    func insertActivityData(type: String, confidence: String) {
         print("DatabaseManager activity type: \(type), confidence: \(confidence)")
         let insertStatementString = "INSERT INTO activity (id, name, confidence, lastUpdatedTime) VALUES (?, ?, ?, ?);"
         var insertStatement: OpaquePointer? = nil

         if sqlite3_prepare_v2(db, insertStatementString, -1, &insertStatement, nil) == SQLITE_OK {
             let columnID = String(Date().timeIntervalSince1970 * 1000)
             let columnNAME = type
             let columnConfidence = confidence
             let columnLastUpTime = String(Date().timeIntervalSince1970 * 1000)
             let SQLITE_TRANSIENT = unsafeBitCast(-1, to: sqlite3_destructor_type.self)
             sqlite3_bind_text(insertStatement, 2, columnNAME.cString(using: .utf8), -1, SQLITE_TRANSIENT)
             sqlite3_bind_text(insertStatement, 3, columnConfidence.cString(using: .utf8), -1, SQLITE_TRANSIENT)
             sqlite3_bind_text(insertStatement, 4, columnLastUpTime.cString(using: .utf8), -1, SQLITE_TRANSIENT)


             if sqlite3_step(insertStatement) == SQLITE_DONE {
                 print("DatabaseManager Successfully inserted row.")
             } else {
                 let errorMessage = String(cString: sqlite3_errmsg(db)!)
                 print("DatabaseManager Failed to insert row. Error: \(errorMessage)")
             }
         } else {
             let errorMessage = String(cString: sqlite3_errmsg(db)!)
             print("DatabaseManager Failed to prepare statement. Error: \(errorMessage)")
         }

         sqlite3_finalize(insertStatement)
    }
}

==> 3.0.1.tar.gz: ios/Classes/DatabaseManager.swift <==
import Foundation
import SQLite3

class DatabaseManager {
    static let shared = DatabaseManager() // Singleton instance

    private var db: OpaquePointer? = nil

    private init() {
        openDatabase()
    }

    private func openDatabase() {
        let dbPath = NSSearchPathForDirectoriesInDomains(.documentDirectory, .userDomainMask, true).first! + "/myDatabase.db"

        if sqlite3_open(dbPath, &db) == SQLITE_OK {
            print("DatabaseManager Successfully opened connection to database.")
        } else {
            let errorMessage = String(cString: sqlite3_errmsg(db)!)
            print("DatabaseManager Unable to open database. Error: \(errorMessage)")
        }
    }

    func insertActivityData(type: String, confidence: String) {
         print("DatabaseManager activity type: \(type), confidence: \(confidence)")
         let insertStatementString = "INSERT INTO activity (id, name, confidence, lastUpdatedTime) VALUES (?, ?, ?, ?);"
         var insertStatement: OpaquePointer? = nil

         // Create a DateFormatter instance
         let dateFormatter = DateFormatter()
         dateFormatter.dateFormat = "dd MMM yyyy h:mm:ss a"
         let startDateString = dateFormatter.string(from: startDate)
         print("converted startDateString: \(startDateString)")

         if sqlite3_prepare_v2(db, insertStatementString, -1, &insertStatement, nil) == SQLITE_OK {
             let columnID = String(Date().timeIntervalSince1970 * 1000)
             let columnNAME = type
             let columnConfidence = confidence
             let columnLastUpTime = startDateString
             let SQLITE_TRANSIENT = unsafeBitCast(-1, to: sqlite3_destructor_type.self)
             sqlite3_bind_text(insertStatement, 2, columnNAME.cString(using: .utf8), -1, SQLITE_TRANSIENT)
             sqlite3_bind_text(insertStatement, 3, columnConfidence.cString(using: .utf8), -1, SQLITE_TRANSIENT)
             sqlite3_bind_text(insertStatement, 4, columnLastUpTime.cString(using: .utf8), -1, SQLITE_TRANSIENT)


             if sqlite3_step(insertStatement) == SQLITE_DONE {
                 print("DatabaseManager Successfully inserted row.")
             } else {
                 let errorMessage = String(cString: sqlite3_errmsg(db)!)
                 print("DatabaseManager Failed to insert row. Error: \(errorMessage)")
             }
         } else {
             let errorMessage = String(cString: sqlite3_errmsg(db)!)
             print("DatabaseManager Failed to prepare statement. Error: \(errorMessage)")
         }

         sqlite3_finalize(insertStatement)
    }
}
